# REL10-BP02: Automate recovery for single-location failures

## Description

Implement automatic failover khi một location fails.

## Implementation Guidance

- Configure automatic health checks
- Set up automatic DNS failover
- Implement database failover
- Test failover automation
- Monitor failover events

## Risk Level

High - Manual failover is slow during incidents.

## Related Best Practices

- [REL10-BP01](REL10-BP01-Deploy-Multiple-Locations.md)
- [REL06-BP04](../REL06-Change-Resource-Monitoring/REL06-BP04-Automate-Responses.md)
